@@ -2,7 +2,7 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.295';
+our $VERSION = '0.296';
 
 use App::cpm::Logger::File;
 use App::cpm::Worker::Installer::Menlo;
@@ -41,18 +41,24 @@ sub work {
             };
         }
     } elsif ($type eq "configure") {
-        my ($distdata, $requirements)
+        my ($distdata, $requirements, $static_builder)
             = $self->configure($job); # $job->{directory}, $job->{distfile}, $job->{meta});
         if ($requirements) {
             return +{
                 ok => 1,
                 distdata => $distdata,
                 requirements => $requirements,
+                static_builder => $static_builder,
             };
         }
     } elsif ($type eq "install") {
-        my $ok = $self->install($job->{directory}, $job->{distdata});
-        rmtree $job->{directory} if $ok; # XXX Carmel!!!
+        my $ok = $self->install($job);
+        if ($ok) {
+            $self->menlo->{logger}->log("Successfully installed distribution");
+            rmtree $job->{directory}; # XXX Carmel!!
+        } else {
+            $self->menlo->{logger}->log("Failed to install distribution");
+        }
         return { ok => $ok };
     } else {
         die "Unknown type: $type\n";
@@ -130,6 +136,7 @@ sub fetch {
         }
     } elsif ($source eq "local") {
         for my $uri (@uri) {
+            $self->menlo->{logger}->log("Copying $uri");
             $uri =~ s{^file://}{};
             my $basename = basename $uri;
             if (-d $uri) {
@@ -158,6 +165,7 @@ sub fetch {
             $clean->($uri);
             my $basename = basename $uri;
             if ($uri =~ s{^file://}{}) {
+                $self->menlo->{logger}->log("Copying $uri");
                 File::Copy::copy($uri, $basename)
                     or next FETCH;
                 $dir = $self->menlo->unpack($basename)
@@ -168,6 +176,7 @@ sub fetch {
                 if ($distfile and $CACHED_MIRROR->($uri)) {
                     my $cache = File::Spec->catfile($self->{cache}, "authors/id/$distfile");
                     if (-f $cache) {
+                        $self->menlo->{logger}->log("Using cache $cache");
                         File::Copy::copy($cache, $basename);
                         $dir = $self->menlo->unpack($basename);
                         unless ($dir) {
@@ -256,19 +265,24 @@ sub _get_configure_requirements {
         $meta = CPAN::Meta->new({name => $d->dist, version => $d->version});
     }
 
-    my $requirements = $self->_extract_requirements($meta, [qw(configure)]);
     my $p = $self->menlo->extract_packages($meta, ".");
     my $provides = [map +{
         package => $_,
         version => $p->{$_}{version} || undef,
     }, sort keys %$p];
 
-    if (!@$requirements and -f "Build.PL" and ($distfile || "") !~ m{/Module-Build-[0-9v]}) {
-        push @$requirements, {package => "Module::Build", version_range => "0.38"};
-    }
+    my $requirements = [];
+    if ($self->menlo->opts_in_static_install($meta)) {
+        $self->menlo->{logger}->log("Distribution opts in x_static_install: $meta->{x_static_install}");
+    } else {
+        $requirements = $self->_extract_requirements($meta, [qw(configure)]);
+        if (!@$requirements and -f "Build.PL" and ($distfile || "") !~ m{/Module-Build-[0-9v]}) {
+            push @$requirements, {package => "Module::Build", version_range => "0.38"};
+        }
 
-    if (NEED_INJECT_TOOLCHAIN_REQS) {
-        $self->_inject_toolchain_reqs($distfile, $requirements);
+        if (NEED_INJECT_TOOLCHAIN_REQS) {
+            $self->_inject_toolchain_reqs($distfile, $requirements);
+        }
     }
     return ($meta ? $meta->as_struct : +{}, $requirements, $provides);
 }
@@ -293,7 +307,14 @@ sub configure {
     my ($dir, $distfile, $meta, $source) = @{$job}{qw(directory distfile meta source)};
     my $guard = pushd $dir;
     my $menlo = $self->menlo;
-    if (-f 'Build.PL') {
+
+    $menlo->{logger}->log("Configuring distribution");
+    my $static_builder;
+    if ($menlo->opts_in_static_install($meta)) {
+        my $state = {};
+        $menlo->static_install_configure($state, "dummy", 1);
+        $static_builder = $state->{static_install};
+    } elsif (-f 'Build.PL') {
         $menlo->configure([ $menlo->{perl}, 'Build.PL' ], 1);
         return unless -f 'Build';
     } elsif (-f 'Makefile.PL') {
@@ -307,7 +328,7 @@ sub configure {
         my $mymeta = CPAN::Meta->load_file($file);
         $requirements = $self->_extract_requirements($mymeta, $phase);
     }
-    return ($distdata, $requirements);
+    return ($distdata, $requirements, $static_builder);
 }
 
 sub _build_distdata {
@@ -334,13 +355,19 @@ sub _build_distdata {
 }
 
 sub install {
-    my ($self, $dir, $distdata) = @_;
-
+    my ($self, $job) = @_;
+    my ($dir, $distdata, $static_builder) = @{$job}{qw(directory distdata static_builder)};
     my $guard = pushd $dir;
     my $menlo = $self->menlo;
 
+    $menlo->{logger}->log("Building " . ($menlo->{notest} ? "" : "and testing ") . "distribution");
     my $installed;
-    if (-f 'Build') {
+    if ($static_builder) {
+        $menlo->build(sub { $static_builder->build }, )
+        && $menlo->test(sub { $static_builder->build("test") }, )
+        && $menlo->install(sub { $static_builder->build("install") }, [])
+        && $installed++;
+    } elsif (-f 'Build') {
         $menlo->build([ $menlo->{perl}, "./Build" ], )
         && $menlo->test([ $menlo->{perl}, "./Build", "test" ], )
         && $menlo->install([ $menlo->{perl}, "./Build", "install" ], [])
