@@ -4,10 +4,9 @@ use warnings;
 use parent 'Menlo::CLI::Compat';
 
 use App::cpm::Logger::File;
-use File::Temp ();
-use POSIX ();
+use Menlo::Builder::Static;
 
-our $VERSION = '0.295';
+our $VERSION = '0.296';
 
 use constant WIN32 => Menlo::CLI::Compat::WIN32();
 
